dispMUA.arDispMUAAllocation["r"] =
{
  "rtl digital newsletter system - www.rtl.be" : [ "rtl_be.png" , "http://www.rtlinfo.be/" ] ,
  "redemption mime converter" : [ "redemption.png" , "http://www.dimastr.com/redemption/" ] ,
  "roving constant contact" : [ "roving_constant_contact.png" ] ,
  "reportsuite mailer" : [ "samriddhi.png" , "http://www.sipl.net/html/reportsuiteoverview.htm" ] ,
  "redmoonstudios" : [ "redmoonstudios_de.png" , "http://www.redmoonstudios.de/" ] ,
  "roxen's email" : [ "roxen.png" ] ,
  "rodriquezmail" : [ "rodriquezmail.png" , "" ] ,
  "rapid-emailer" : [ "rapid-emailer.png" , "http://www.absolutefuturity.com/Rapid-Emailer.htm" ] ,
  "rss2email" : [ "infogami.png" , "http://rss2email.infogami.com/" ] ,
  "roundcube" : [ "roundcube.png" , "http://www.roundcube.net/" ] ,
  "reportbug" : [ "debian.png" , "http://www.debian.org/" ] ,
  "ru.board" : [ "ru_board.png" ] ,
  "reservit" : [ "reservit.png" , "http://www.reservit.com/" ] ,
  "rmrnews" : [ "rmr.png" ] ,
  "redmine" : [ "ruby.png" , "http://www.redmine.org/" ] ,
  "rscomm" : [ "rscomm.png" , "http://www.reinhardt-software.de/" ] ,
  "ramail" : [ "rambler_ru.png" , "http://www.rambler.ru/" ] ,
  "reo" : [ "t-online.png" , "http://www.t-online.de/" ] ,
}
